:mod:`art.estimators.gan`
=========================
.. automodule:: art.estimators.gan

TensorFlowV2 GAN
----------------
.. autoclass:: TensorFlowV2GAN
   :members:
   :special-members: __init__
   :inherited-members:
